@@ -7,12 +7,12 @@ Copyright (C) 2003 - 2005 Klaus Niederkrueger
 
 Copyright (C) 1996 - 2000 Bernd Johannes Wuebben
                           wuebben@kde.org
-						  
+
 Copyright (C) 1995        Martin Bartlett
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License as
-published by the Free Software Foundation; either version 2 of 
+published by the Free Software Foundation; either version 2 of
 the License, or (at your option) any later version.
 
 This program is distributed in the hope that it will be useful,
@@ -29,100 +29,123 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 #include <QDebug>
 
-namespace {
-
-KNumber Deg2Rad(const KNumber &x) {
-	return x * (KNumber::Pi() / KNumber(180));
+namespace
+{
+KNumber Deg2Rad(const KNumber &x)
+{
+    return x * (KNumber::Pi() / KNumber(180));
 }
 
-KNumber Gra2Rad(const KNumber &x) {
-	return x * (KNumber::Pi() / KNumber(200));
+KNumber Gra2Rad(const KNumber &x)
+{
+    return x * (KNumber::Pi() / KNumber(200));
 }
 
-KNumber Rad2Deg(const KNumber &x) {
-	 return x * (KNumber(180) / KNumber::Pi());
+KNumber Rad2Deg(const KNumber &x)
+{
+    return x * (KNumber(180) / KNumber::Pi());
 }
 
-KNumber Rad2Gra(const KNumber &x) {
-	return x * (KNumber(200) / KNumber::Pi());
+KNumber Rad2Gra(const KNumber &x)
+{
+    return x * (KNumber(200) / KNumber::Pi());
 }
 
 bool error_;
 
-KNumber ExecOr(const KNumber &left_op, const KNumber &right_op) {
+KNumber ExecOr(const KNumber &left_op, const KNumber &right_op)
+{
     return left_op | right_op;
 }
 
-KNumber ExecXor(const KNumber &left_op, const KNumber &right_op) {
+KNumber ExecXor(const KNumber &left_op, const KNumber &right_op)
+{
     return left_op ^ right_op;
 }
 
-KNumber ExecAnd(const KNumber &left_op, const KNumber &right_op) {
+KNumber ExecAnd(const KNumber &left_op, const KNumber &right_op)
+{
     return left_op & right_op;
 }
 
-KNumber ExecLsh(const KNumber &left_op, const KNumber &right_op) {
+KNumber ExecLsh(const KNumber &left_op, const KNumber &right_op)
+{
     return left_op << right_op;
 }
 
-KNumber ExecRsh(const KNumber &left_op, const KNumber &right_op) {
+KNumber ExecRsh(const KNumber &left_op, const KNumber &right_op)
+{
     return left_op >> right_op;
 }
 
-KNumber ExecAdd(const KNumber &left_op, const KNumber &right_op) {
+KNumber ExecAdd(const KNumber &left_op, const KNumber &right_op)
+{
     return left_op + right_op;
 }
 
-KNumber ExecSubtract(const KNumber &left_op, const KNumber &right_op) {
+KNumber ExecSubtract(const KNumber &left_op, const KNumber &right_op)
+{
     return left_op - right_op;
 }
 
-KNumber ExecMultiply(const KNumber &left_op, const KNumber &right_op) {
+KNumber ExecMultiply(const KNumber &left_op, const KNumber &right_op)
+{
     return left_op * right_op;
 }
 
-KNumber ExecDivide(const KNumber &left_op, const KNumber &right_op) {
+KNumber ExecDivide(const KNumber &left_op, const KNumber &right_op)
+{
     return left_op / right_op;
 }
 
-KNumber ExecMod(const KNumber &left_op, const KNumber &right_op) {
+KNumber ExecMod(const KNumber &left_op, const KNumber &right_op)
+{
     return left_op % right_op;
 }
 
-KNumber ExecIntDiv(const KNumber &left_op, const KNumber &right_op) {
+KNumber ExecIntDiv(const KNumber &left_op, const KNumber &right_op)
+{
     return (left_op / right_op).integerPart();
 }
 
-KNumber ExecBinom(const KNumber &left_op, const KNumber &right_op) {
-	return left_op.bin(right_op);
+KNumber ExecBinom(const KNumber &left_op, const KNumber &right_op)
+{
+    return left_op.bin(right_op);
 }
 
-KNumber ExecPower(const KNumber &left_op, const KNumber &right_op) {
+KNumber ExecPower(const KNumber &left_op, const KNumber &right_op)
+{
     return left_op.pow(right_op);
 }
 
-KNumber ExecPwrRoot(const KNumber &left_op, const KNumber &right_op) {
+KNumber ExecPwrRoot(const KNumber &left_op, const KNumber &right_op)
+{
     return left_op.pow(KNumber::One / right_op);
 }
 
-KNumber ExecAddP(const KNumber &left_op, const KNumber &right_op) {
+KNumber ExecAddP(const KNumber &left_op, const KNumber &right_op)
+{
     return left_op * (KNumber::One + right_op / KNumber(100));
 }
 
-KNumber ExecSubP(const KNumber &left_op, const KNumber &right_op) {
+KNumber ExecSubP(const KNumber &left_op, const KNumber &right_op)
+{
     return left_op * (KNumber::One - right_op / KNumber(100));
 }
 
-KNumber ExecMultiplyP(const KNumber &left_op, const KNumber &right_op) {
+KNumber ExecMultiplyP(const KNumber &left_op, const KNumber &right_op)
+{
     return left_op * right_op / KNumber(100);
 }
 
-KNumber ExecDivideP(const KNumber &left_op, const KNumber &right_op) {
+KNumber ExecDivideP(const KNumber &left_op, const KNumber &right_op)
+{
     return left_op * KNumber(100) / right_op;
 }
 
 // move a number into the interval [0,360) by adding multiples of 360
-KNumber moveIntoDegInterval(const KNumber &num) {
+KNumber moveIntoDegInterval(const KNumber &num)
+{
     KNumber tmp_num = num - (num / KNumber(360)).integerPart() * KNumber(360);
     if (tmp_num < KNumber::Zero)
         return tmp_num + KNumber(360);
@@ -130,41 +153,42 @@ KNumber moveIntoDegInterval(const KNumber &num) {
 }
 
 // move a number into the interval [0,400) by adding multiples of 400
-KNumber moveIntoGradInterval(const KNumber &num) {
+KNumber moveIntoGradInterval(const KNumber &num)
+{
     KNumber tmp_num = num - (num / KNumber(400)).integerPart() * KNumber(400);
     if (tmp_num < KNumber::Zero)
         return tmp_num + KNumber(400);
     return tmp_num;
 }
 
-typedef KNumber(*Arith)(const KNumber &, const KNumber &);
-typedef KNumber(*Prcnt)(const KNumber &, const KNumber &);
+typedef KNumber (*Arith)(const KNumber &, const KNumber &);
+typedef KNumber (*Prcnt)(const KNumber &, const KNumber &);
 
 struct operator_data {
-    int precedence;  // priority of operators in " enum Operation"
+    int precedence; // priority of operators in " enum Operation"
     Arith arith_ptr;
     Prcnt prcnt_ptr;
 };
 
 // build precedence list
 const struct operator_data Operator[] = {
-    { 0, nullptr,         nullptr},          // FUNC_EQUAL
-    { 0, nullptr,         nullptr},          // FUNC_PERCENT
-    { 0, nullptr,         nullptr},          // FUNC_BRACKET
-    { 1, ExecOr,       nullptr},          // FUNC_OR
-    { 2, ExecXor,      nullptr},          // FUNC_XOR
-    { 3, ExecAnd,      nullptr},          // FUNC_AND
-    { 4, ExecLsh,      nullptr},          // FUNC_LSH
-    { 4, ExecRsh,      nullptr},          // FUNC_RSH
-    { 5, ExecAdd,      ExecAddP},      // FUNC_ADD
-    { 5, ExecSubtract, ExecSubP},      // FUNC_SUBTRACT
-    { 6, ExecMultiply, ExecMultiplyP}, // FUNC_MULTIPLY
-    { 6, ExecDivide,   ExecDivideP},   // FUNC_DIVIDE
-    { 6, ExecMod,      nullptr},          // FUNC_MOD
-    { 6, ExecIntDiv,   nullptr},          // FUNC_INTDIV
-    { 7, ExecBinom,    nullptr},          // FUNC_BINOM
-    { 7, ExecPower,    nullptr},          // FUNC_POWER
-    { 7, ExecPwrRoot,  nullptr}           // FUNC_PWR_ROOT
+    {0, nullptr, nullptr}, // FUNC_EQUAL
+    {0, nullptr, nullptr}, // FUNC_PERCENT
+    {0, nullptr, nullptr}, // FUNC_BRACKET
+    {1, ExecOr, nullptr}, // FUNC_OR
+    {2, ExecXor, nullptr}, // FUNC_XOR
+    {3, ExecAnd, nullptr}, // FUNC_AND
+    {4, ExecLsh, nullptr}, // FUNC_LSH
+    {4, ExecRsh, nullptr}, // FUNC_RSH
+    {5, ExecAdd, ExecAddP}, // FUNC_ADD
+    {5, ExecSubtract, ExecSubP}, // FUNC_SUBTRACT
+    {6, ExecMultiply, ExecMultiplyP}, // FUNC_MULTIPLY
+    {6, ExecDivide, ExecDivideP}, // FUNC_DIVIDE
+    {6, ExecMod, nullptr}, // FUNC_MOD
+    {6, ExecIntDiv, nullptr}, // FUNC_INTDIV
+    {7, ExecBinom, nullptr}, // FUNC_BINOM
+    {7, ExecPower, nullptr}, // FUNC_POWER
+    {7, ExecPwrRoot, nullptr} // FUNC_PWR_ROOT
 };
 
 }
@@ -174,15 +198,15 @@ CalcEngine::CalcEngine()
     , percent_mode_(false)
     , repeat_mode_(false)
 {
-
     last_number_ = KNumber::Zero;
     error_ = false;
     last_operation_ = FUNC_EQUAL;
 }
 
-KNumber CalcEngine::lastOutput(bool &error) const {
-	error = error_;
-	return last_number_;
+KNumber CalcEngine::lastOutput(bool &error) const
+{
+    error = error_;
+    return last_number_;
 }
 
 void CalcEngine::ArcCosDeg(const KNumber &input)
@@ -197,7 +221,7 @@ void CalcEngine::ArcCosDeg(const KNumber &input)
             last_number_ = KNumber::Zero;
             return;
         }
-        if (input == - KNumber::One) {
+        if (input == -KNumber::One) {
             last_number_ = KNumber(180);
             return;
         }
@@ -229,7 +253,7 @@ void CalcEngine::ArcCosGrad(const KNumber &input)
             last_number_ = KNumber::Zero;
             return;
         }
-        if (input == - KNumber::One) {
+        if (input == -KNumber::One) {
             last_number_ = KNumber(200);
             return;
         }
@@ -243,8 +267,7 @@ void CalcEngine::ArcCosGrad(const KNumber &input)
 
 void CalcEngine::ArcSinDeg(const KNumber &input)
 {
-    if (input.type() == KNumber::TYPE_ERROR  ||
-            input < -KNumber::One || input > KNumber::One) {
+    if (input.type() == KNumber::TYPE_ERROR || input < -KNumber::One || input > KNumber::One) {
         last_number_ = KNumber::NaN;
         return;
     }
@@ -253,7 +276,7 @@ void CalcEngine::ArcSinDeg(const KNumber &input)
             last_number_ = KNumber(90);
             return;
         }
-        if (input == - KNumber::One) {
+        if (input == -KNumber::One) {
             last_number_ = KNumber(-90);
             return;
         }
@@ -267,8 +290,7 @@ void CalcEngine::ArcSinDeg(const KNumber &input)
 
 void CalcEngine::ArcSinRad(const KNumber &input)
 {
-    if (input.type() == KNumber::TYPE_ERROR  ||
-            input < -KNumber::One || input > KNumber::One) {
+    if (input.type() == KNumber::TYPE_ERROR || input < -KNumber::One || input > KNumber::One) {
         last_number_ = KNumber::NaN;
         return;
     }
@@ -277,8 +299,7 @@ void CalcEngine::ArcSinRad(const KNumber &input)
 
 void CalcEngine::ArcSinGrad(const KNumber &input)
 {
-    if (input.type() == KNumber::TYPE_ERROR  ||
-            input < -KNumber::One || input > KNumber::One) {
+    if (input.type() == KNumber::TYPE_ERROR || input < -KNumber::One || input > KNumber::One) {
         last_number_ = KNumber::NaN;
         return;
     }
@@ -287,7 +308,7 @@ void CalcEngine::ArcSinGrad(const KNumber &input)
             last_number_ = KNumber(100);
             return;
         }
-        if (input == - KNumber::One) {
+        if (input == -KNumber::One) {
             last_number_ = KNumber(-100);
             return;
         }
@@ -302,9 +323,12 @@ void CalcEngine::ArcSinGrad(const KNumber &input)
 void CalcEngine::ArcTangensDeg(const KNumber &input)
 {
     if (input.type() == KNumber::TYPE_ERROR) {
-        if (input == KNumber::NaN) last_number_ = KNumber::NaN;
-        if (input == KNumber::PosInfinity) last_number_ = KNumber(90);
-        if (input == KNumber::NegInfinity)  last_number_ = KNumber(-90);
+        if (input == KNumber::NaN)
+            last_number_ = KNumber::NaN;
+        if (input == KNumber::PosInfinity)
+            last_number_ = KNumber(90);
+        if (input == KNumber::NegInfinity)
+            last_number_ = KNumber(-90);
         return;
     }
 
@@ -314,7 +338,8 @@ void CalcEngine::ArcTangensDeg(const KNumber &input)
 void CalcEngine::ArcTangensRad(const KNumber &input)
 {
     if (input.type() == KNumber::TYPE_ERROR) {
-        if (input == KNumber::NaN) last_number_ = KNumber::NaN;
+        if (input == KNumber::NaN)
+            last_number_ = KNumber::NaN;
         if (input == KNumber::PosInfinity)
             last_number_ = KNumber::Pi() / KNumber(2);
         if (input == KNumber::NegInfinity)
@@ -328,9 +353,12 @@ void CalcEngine::ArcTangensRad(const KNumber &input)
 void CalcEngine::ArcTangensGrad(const KNumber &input)
 {
     if (input.type() == KNumber::TYPE_ERROR) {
-        if (input == KNumber::NaN)         last_number_ = KNumber::NaN;
-        if (input == KNumber::PosInfinity) last_number_ = KNumber(100);
-        if (input == KNumber::NegInfinity) last_number_ = KNumber(-100);
+        if (input == KNumber::NaN)
+            last_number_ = KNumber::NaN;
+        if (input == KNumber::PosInfinity)
+            last_number_ = KNumber(100);
+        if (input == KNumber::NegInfinity)
+            last_number_ = KNumber(-100);
         return;
     }
 
@@ -340,9 +368,12 @@ void CalcEngine::ArcTangensGrad(const KNumber &input)
 void CalcEngine::AreaCosHyp(const KNumber &input)
 {
     if (input.type() == KNumber::TYPE_ERROR) {
-        if (input == KNumber::NaN)         last_number_ = KNumber::NaN;
-        if (input == KNumber::PosInfinity) last_number_ = KNumber::PosInfinity;
-        if (input == KNumber::NegInfinity) last_number_ = KNumber::NaN;
+        if (input == KNumber::NaN)
+            last_number_ = KNumber::NaN;
+        if (input == KNumber::PosInfinity)
+            last_number_ = KNumber::PosInfinity;
+        if (input == KNumber::NegInfinity)
+            last_number_ = KNumber::NaN;
         return;
     }
 
@@ -360,9 +391,12 @@ void CalcEngine::AreaCosHyp(const KNumber &input)
 void CalcEngine::AreaSinHyp(const KNumber &input)
 {
     if (input.type() == KNumber::TYPE_ERROR) {
-        if (input == KNumber::NaN)         last_number_ = KNumber::NaN;
-        if (input == KNumber::PosInfinity) last_number_ = KNumber::PosInfinity;
-        if (input == KNumber::NegInfinity) last_number_ = KNumber::NegInfinity;
+        if (input == KNumber::NaN)
+            last_number_ = KNumber::NaN;
+        if (input == KNumber::PosInfinity)
+            last_number_ = KNumber::PosInfinity;
+        if (input == KNumber::NegInfinity)
+            last_number_ = KNumber::NegInfinity;
         return;
     }
 
@@ -388,7 +422,7 @@ void CalcEngine::AreaTangensHyp(const KNumber &input)
         last_number_ = KNumber::PosInfinity;
         return;
     }
-    if (input == - KNumber::One) {
+    if (input == -KNumber::One) {
         last_number_ = KNumber::NegInfinity;
         return;
     }
@@ -411,10 +445,10 @@ void CalcEngine::CosDeg(const KNumber &input)
         last_number_ = KNumber::NaN;
         return;
     }
-	
+
     KNumber trunc_input = moveIntoDegInterval(input);
-    
-	if (trunc_input.type() == KNumber::TYPE_INTEGER) {
+
+    if (trunc_input.type() == KNumber::TYPE_INTEGER) {
         KNumber mult = trunc_input / KNumber(90);
         if (mult.type() == KNumber::TYPE_INTEGER) {
             if (mult == KNumber::Zero)
@@ -425,11 +459,12 @@ void CalcEngine::CosDeg(const KNumber &input)
                 last_number_ = KNumber::NegOne;
             else if (mult == KNumber(3))
                 last_number_ = KNumber::Zero;
-            else qDebug() << "Something wrong in CalcEngine::CosDeg";
+            else
+                qDebug() << "Something wrong in CalcEngine::CosDeg";
             return;
         }
     }
-		
+
     trunc_input = Deg2Rad(trunc_input);
     last_number_ = trunc_input.cos();
 }
@@ -440,7 +475,7 @@ void CalcEngine::CosRad(const KNumber &input)
         last_number_ = KNumber::NaN;
         return;
     }
-	
+
     last_number_ = input.cos();
 }
 
@@ -462,7 +497,8 @@ void CalcEngine::CosGrad(const KNumber &input)
                 last_number_ = KNumber::NegOne;
             else if (mult == KNumber(3))
                 last_number_ = KNumber::Zero;
-            else qDebug() << "Something wrong in CalcEngine::CosGrad";
+            else
+                qDebug() << "Something wrong in CalcEngine::CosGrad";
             return;
         }
     }
@@ -474,13 +510,16 @@ void CalcEngine::CosGrad(const KNumber &input)
 void CalcEngine::CosHyp(const KNumber &input)
 {
     if (input.type() == KNumber::TYPE_ERROR) {
-        if (input == KNumber::NaN)         last_number_ = KNumber::NaN;
-        if (input == KNumber::PosInfinity) last_number_ = KNumber::PosInfinity;
-		// YES, this should be *positive* infinity. We mimic the behavior of 
-		// libc which says the following for cosh
-		//
-		// "If x is positive infinity or negative infinity, positive infinity is returned."
-        if (input == KNumber::NegInfinity) last_number_ = KNumber::PosInfinity;
+        if (input == KNumber::NaN)
+            last_number_ = KNumber::NaN;
+        if (input == KNumber::PosInfinity)
+            last_number_ = KNumber::PosInfinity;
+        // YES, this should be *positive* infinity. We mimic the behavior of
+        // libc which says the following for cosh
+        //
+        // "If x is positive infinity or negative infinity, positive infinity is returned."
+        if (input == KNumber::NegInfinity)
+            last_number_ = KNumber::PosInfinity;
         return;
     }
 
@@ -500,9 +539,12 @@ void CalcEngine::CubeRoot(const KNumber &input)
 void CalcEngine::Exp(const KNumber &input)
 {
     if (input.type() == KNumber::TYPE_ERROR) {
-        if (input == KNumber::NaN)         last_number_ = KNumber::NaN;
-        if (input == KNumber::PosInfinity) last_number_ = KNumber::PosInfinity;
-        if (input == KNumber::NegInfinity) last_number_ = KNumber::Zero;
+        if (input == KNumber::NaN)
+            last_number_ = KNumber::NaN;
+        if (input == KNumber::PosInfinity)
+            last_number_ = KNumber::PosInfinity;
+        if (input == KNumber::NegInfinity)
+            last_number_ = KNumber::Zero;
         return;
     }
     last_number_ = KNumber::Euler().pow(input);
@@ -511,36 +553,40 @@ void CalcEngine::Exp(const KNumber &input)
 void CalcEngine::Exp10(const KNumber &input)
 {
     if (input.type() == KNumber::TYPE_ERROR) {
-        if (input == KNumber::NaN)         last_number_ = KNumber::NaN;
-        if (input == KNumber::PosInfinity) last_number_ = KNumber::PosInfinity;
-        if (input == KNumber::NegInfinity) last_number_ = KNumber::Zero;
+        if (input == KNumber::NaN)
+            last_number_ = KNumber::NaN;
+        if (input == KNumber::PosInfinity)
+            last_number_ = KNumber::PosInfinity;
+        if (input == KNumber::NegInfinity)
+            last_number_ = KNumber::Zero;
         return;
     }
     last_number_ = KNumber(10).pow(input);
 }
 
-
 void CalcEngine::Factorial(const KNumber &input)
 {
-    if (input == KNumber::PosInfinity) return;
+    if (input == KNumber::PosInfinity)
+        return;
     if (input < KNumber::Zero || input.type() == KNumber::TYPE_ERROR) {
         error_ = true;
         last_number_ = KNumber::NaN;
         return;
     }
-	
+
     last_number_ = input.integerPart().factorial();
 }
 
 void CalcEngine::Gamma(const KNumber &input)
 {
-    if (input == KNumber::PosInfinity) return;
+    if (input == KNumber::PosInfinity)
+        return;
     if (input < KNumber::Zero || input.type() == KNumber::TYPE_ERROR) {
         error_ = true;
         last_number_ = KNumber::NaN;
         return;
     }
-	
+
     last_number_ = input.tgamma();
 }
 
@@ -598,7 +644,6 @@ void CalcEngine::Reciprocal(const KNumber &input)
     last_number_ = KNumber::One / input;
 }
 
-
 void CalcEngine::SinDeg(const KNumber &input)
 {
     if (input.type() == KNumber::TYPE_ERROR) {
@@ -618,7 +663,8 @@ void CalcEngine::SinDeg(const KNumber &input)
                 last_number_ = KNumber::Zero;
             else if (mult == KNumber(3))
                 last_number_ = KNumber::NegOne;
-            else qDebug() << "Something wrong in CalcEngine::SinDeg";
+            else
+                qDebug() << "Something wrong in CalcEngine::SinDeg";
             return;
         }
     }
@@ -656,7 +702,8 @@ void CalcEngine::SinGrad(const KNumber &input)
                 last_number_ = KNumber::Zero;
             else if (mult == KNumber(3))
                 last_number_ = KNumber::NegOne;
-            else qDebug() << "Something wrong in CalcEngine::SinGrad";
+            else
+                qDebug() << "Something wrong in CalcEngine::SinGrad";
             return;
         }
     }
@@ -669,9 +716,12 @@ void CalcEngine::SinGrad(const KNumber &input)
 void CalcEngine::SinHyp(const KNumber &input)
 {
     if (input.type() == KNumber::TYPE_ERROR) {
-        if (input == KNumber::NaN)         last_number_ = KNumber::NaN;
-        if (input == KNumber::PosInfinity) last_number_ = KNumber::PosInfinity;
-        if (input == KNumber::NegInfinity) last_number_ = KNumber::NegInfinity;
+        if (input == KNumber::NaN)
+            last_number_ = KNumber::NaN;
+        if (input == KNumber::PosInfinity)
+            last_number_ = KNumber::PosInfinity;
+        if (input == KNumber::NegInfinity)
+            last_number_ = KNumber::NegInfinity;
         return;
     }
 
@@ -806,14 +856,17 @@ void CalcEngine::TangensGrad(const KNumber &input)
 
 void CalcEngine::TangensHyp(const KNumber &input)
 {
-	if (input.type() == KNumber::TYPE_ERROR) {
-		if (input == KNumber::NaN)         last_number_ = KNumber::NaN;
-		if (input == KNumber::PosInfinity) last_number_ = KNumber::One;
-		if (input == KNumber::NegInfinity) last_number_ = KNumber::NegOne;
-		return;
-	}
+    if (input.type() == KNumber::TYPE_ERROR) {
+        if (input == KNumber::NaN)
+            last_number_ = KNumber::NaN;
+        if (input == KNumber::PosInfinity)
+            last_number_ = KNumber::One;
+        if (input == KNumber::NegInfinity)
+            last_number_ = KNumber::NegOne;
+        return;
+    }
 
-	last_number_ = input.tanh();
+    last_number_ = input.tanh();
 }
 
 KNumber CalcEngine::evalOperation(const KNumber &arg1, Operation operation, const KNumber &arg2)
@@ -826,7 +879,7 @@ KNumber CalcEngine::evalOperation(const KNumber &arg1, Operation operation, cons
     }
 }
 
-void CalcEngine::enterOperation(const KNumber &number, Operation func)
+void CalcEngine::enterOperation(const KNumber &number, Operation func, Repeat allow_repeat)
 {
     Node tmp_node;
 
@@ -856,7 +909,7 @@ void CalcEngine::enterOperation(const KNumber &number, Operation func)
             if (!repeat_mode_) {
                 repeat_mode_ = last_operation_ != FUNC_EQUAL;
                 last_repeat_number_ = number;
-            } else {
+            } else if (allow_repeat == REPEAT_ALLOW) {
                 Node repeat_node;
                 repeat_node.operation = last_operation_;
                 repeat_node.number = number;
@@ -866,8 +919,7 @@ void CalcEngine::enterOperation(const KNumber &number, Operation func)
         }
     }
 
-    if (getOnlyUpdateOperation() && !stack_.isEmpty() &&
-        !(func == FUNC_EQUAL || func == FUNC_PERCENT))
+    if (getOnlyUpdateOperation() && !stack_.isEmpty() && !(func == FUNC_EQUAL || func == FUNC_PERCENT))
         stack_.top().operation = func;
     else
         stack_.push(tmp_node);
@@ -886,18 +938,17 @@ bool CalcEngine::evalStack()
 
     Node tmp_node = stack_.pop();
 
-    while (! stack_.isEmpty()) {
+    while (!stack_.isEmpty()) {
         Node tmp_node2 = stack_.pop();
-        if (Operator[tmp_node.operation].precedence <=
-                Operator[tmp_node2.operation].precedence) {
-            if (tmp_node2.operation == FUNC_BRACKET) continue;
-			const KNumber tmp_result = evalOperation(tmp_node2.number, tmp_node2.operation, tmp_node.number);
+        if (Operator[tmp_node.operation].precedence <= Operator[tmp_node2.operation].precedence) {
+            if (tmp_node2.operation == FUNC_BRACKET)
+                continue;
+            const KNumber tmp_result = evalOperation(tmp_node2.number, tmp_node2.operation, tmp_node.number);
             tmp_node.number = tmp_result;
         } else {
             stack_.push(tmp_node2);
             break;
         }
-
     }
 
     if (tmp_node.operation != FUNC_EQUAL && tmp_node.operation != FUNC_PERCENT)
@@ -928,4 +979,3 @@ bool CalcEngine::getOnlyUpdateOperation() const
 {
     return only_update_operation_;
 }
-
