@@ -22,11 +22,10 @@
 
 #include <KLocalizedString>
 
-
-
 KCalcStatusBar::KCalcStatusBar(QWidget *parent)
     : QStatusBar(parent)
-    , shift_indicator_(addIndicator(QList<QString>() << i18nc("Normal button functions are active", "NORM") << i18nc("Second button functions are active", "SHIFT")))
+    , shift_indicator_(
+          addIndicator(QList<QString>() << i18nc("Normal button functions are active", "NORM") << i18nc("Second button functions are active", "SHIFT")))
     , base_indicator_(addIndicator(QList<QString>() << QStringLiteral("DEC") << QStringLiteral("BIN") << QStringLiteral("OCT") << QStringLiteral("HEX")))
     , angle_mode_indicator_(addIndicator(QList<QString>() << QStringLiteral("DEG") << QStringLiteral("RAD") << QStringLiteral("GRA")))
     , memory_indicator_(addIndicator(QList<QString>() << QString() << i18nc("Memory indicator in status bar", "M")))
@@ -34,14 +33,14 @@ KCalcStatusBar::KCalcStatusBar(QWidget *parent)
     setSizeGripEnabled(false);
 }
 
-QLabel *KCalcStatusBar::addIndicator(QList<QString> indicatorTexts)
+QLabel *KCalcStatusBar::addIndicator(const QList<QString> &indicatorTexts)
 {
-    QLabel *l = new QLabel(indicatorTexts.at(0), this);
+    auto l = new QLabel(indicatorTexts.at(0), this);
 
     // find widest indicator text
     QFontMetrics fm(l->font());
     int maxWidth = 0;
-    foreach (const QString &text, indicatorTexts) {
+    for (const QString &text : indicatorTexts) {
         maxWidth = qMax(maxWidth, fm.boundingRect(text).width());
     }
     // add some padding
@@ -113,4 +112,3 @@ void KCalcStatusBar::setMemoryIndicator(bool memory)
 {
     memory_indicator_->setText(memory ? i18nc("Memory indicator in status bar", "M") : QString());
 }
-
